*==============================================================================
* Procedure:      DebugMode
* Purpose:        Places the application in debug mode if the debug.txt
*                 file is present. Useful in place of using the SUSPEND
*                 command, so the application won't be suspended when
*                 deployed if you forget to remove the call to DebugMode.
*
* Author:         F1 Technologies
*                 White Light Computing, Inc. (modifications)
*
* Parameters:     tlMode, Logical (optional) .T. starts debug mode, .F. 
*                 closes the debugger.
*                 tcMessage, Character (optional), an additional message to
*                 display in the debugmode messagebox call.
*
* Modifications..:
* 08/28/2000      Do not prompt if a debug window already exists.
* 02/27/2002      Added support for an optional message.
* 06/12/2003      Replaced values with constants.
* 04/20/2004      RAS - Do not run if this is called during runtime
*==============================================================================
LPARAMETERS tlMode, tcMessage

#INCLUDE FoxPro.h

LOCAL lnProgram, ;
      lcMessage

IF NOT FILE("DEBUG.TXT") OR VERSION(2) = 0
   RETURN
ENDIF

IF PCOUNT() = 0 OR tlMode
   lnProgram = PROGRAM(-1)
   lcMessage = "Called from " + ;
               PROGRAM(lnProgram-1) + ;
               CHR(13) + CHR(13) + ;
               "Enter Debug Mode?"

   IF PCOUNT() = 2
      lcMessage = lcMessage + CHR(13) + tcMessage
   ENDIF

   * Check to see of already in a debugging session
   IF NOT ( WEXIST("WATCH") OR WEXIST("TRACE") ;
         OR WEXIST("CALL STACK") OR WEXIST("LOCALS") ;
         OR WEXIST("DEBUG OUTPUT") )

      * See if developer wants to enter debugging session
      IF MESSAGEBOX(lcMessage , MB_YESNO + MB_ICONQUESTION,_SCREEN.Caption) = IDYES
         DEBUG
         SUSPEND
      ENDIF
   ENDIF
ELSE
   CLOSE DEBUGGER
ENDIF

RETURN
*: EOF :*